Class: TemplateFox::AgentJobStatusResponse

Inherits:
ApiModelBase show all
Defined in:
lib/templatefox/models/agent_job_status_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AgentJobStatusResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/templatefox/models/agent_job_status_response.rb', line 129

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TemplateFox::AgentJobStatusResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TemplateFox::AgentJobStatusResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  end

  if attributes.key?(:'preview_url')
    self.preview_url = attributes[:'preview_url']
  end

  if attributes.key?(:'preview_expires_at')
    self.preview_expires_at = attributes[:'preview_expires_at']
  end

  if attributes.key?(:'notes')
    self.notes = attributes[:'notes']
  end

  if attributes.key?(:'credits_charged')
    self.credits_charged = attributes[:'credits_charged']
  else
    self.credits_charged = nil
  end

  if attributes.key?(:'error_message')
    self.error_message = attributes[:'error_message']
  end

  if attributes.key?(:'error_code')
    self.error_code = attributes[:'error_code']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'completed_at')
    self.completed_at = attributes[:'completed_at']
  end
end

Instance Attribute Details

#completed_atObject

Returns the value of attribute completed_at.



42
43
44
# File 'lib/templatefox/models/agent_job_status_response.rb', line 42

def completed_at
  @completed_at
end

#created_atObject

Returns the value of attribute created_at.



38
39
40
# File 'lib/templatefox/models/agent_job_status_response.rb', line 38

def created_at
  @created_at
end

#credits_chargedObject

Returns the value of attribute credits_charged.



32
33
34
# File 'lib/templatefox/models/agent_job_status_response.rb', line 32

def credits_charged
  @credits_charged
end

#error_codeObject

Returns the value of attribute error_code.



36
37
38
# File 'lib/templatefox/models/agent_job_status_response.rb', line 36

def error_code
  @error_code
end

#error_messageObject

Returns the value of attribute error_message.



34
35
36
# File 'lib/templatefox/models/agent_job_status_response.rb', line 34

def error_message
  @error_message
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/templatefox/models/agent_job_status_response.rb', line 18

def id
  @id
end

#kindObject

Returns the value of attribute kind.



20
21
22
# File 'lib/templatefox/models/agent_job_status_response.rb', line 20

def kind
  @kind
end

#notesObject

Returns the value of attribute notes.



30
31
32
# File 'lib/templatefox/models/agent_job_status_response.rb', line 30

def notes
  @notes
end

#preview_expires_atObject

Returns the value of attribute preview_expires_at.



28
29
30
# File 'lib/templatefox/models/agent_job_status_response.rb', line 28

def preview_expires_at
  @preview_expires_at
end

#preview_urlObject

Returns the value of attribute preview_url.



26
27
28
# File 'lib/templatefox/models/agent_job_status_response.rb', line 26

def preview_url
  @preview_url
end

#statusObject

Returns the value of attribute status.



22
23
24
# File 'lib/templatefox/models/agent_job_status_response.rb', line 22

def status
  @status
end

#template_idObject

Returns the value of attribute template_id.



24
25
26
# File 'lib/templatefox/models/agent_job_status_response.rb', line 24

def template_id
  @template_id
end

#updated_atObject

Returns the value of attribute updated_at.



40
41
42
# File 'lib/templatefox/models/agent_job_status_response.rb', line 40

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



86
87
88
# File 'lib/templatefox/models/agent_job_status_response.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/templatefox/models/agent_job_status_response.rb', line 91

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/templatefox/models/agent_job_status_response.rb', line 67

def self.attribute_map
  {
    :'id' => :'id',
    :'kind' => :'kind',
    :'status' => :'status',
    :'template_id' => :'template_id',
    :'preview_url' => :'preview_url',
    :'preview_expires_at' => :'preview_expires_at',
    :'notes' => :'notes',
    :'credits_charged' => :'credits_charged',
    :'error_message' => :'error_message',
    :'error_code' => :'error_code',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at',
    :'completed_at' => :'completed_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/templatefox/models/agent_job_status_response.rb', line 350

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



115
116
117
118
119
120
121
122
123
124
125
# File 'lib/templatefox/models/agent_job_status_response.rb', line 115

def self.openapi_nullable
  Set.new([
    :'template_id',
    :'preview_url',
    :'preview_expires_at',
    :'notes',
    :'error_message',
    :'error_code',
    :'completed_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/templatefox/models/agent_job_status_response.rb', line 96

def self.openapi_types
  {
    :'id' => :'String',
    :'kind' => :'String',
    :'status' => :'AppRoutersV1AgentJobStatus',
    :'template_id' => :'String',
    :'preview_url' => :'String',
    :'preview_expires_at' => :'String',
    :'notes' => :'String',
    :'credits_charged' => :'Integer',
    :'error_message' => :'String',
    :'error_code' => :'String',
    :'created_at' => :'String',
    :'updated_at' => :'String',
    :'completed_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/templatefox/models/agent_job_status_response.rb', line 317

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      kind == o.kind &&
      status == o.status &&
      template_id == o.template_id &&
      preview_url == o.preview_url &&
      preview_expires_at == o.preview_expires_at &&
      notes == o.notes &&
      credits_charged == o.credits_charged &&
      error_message == o.error_message &&
      error_code == o.error_code &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      completed_at == o.completed_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


337
338
339
# File 'lib/templatefox/models/agent_job_status_response.rb', line 337

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



343
344
345
# File 'lib/templatefox/models/agent_job_status_response.rb', line 343

def hash
  [id, kind, status, template_id, preview_url, preview_expires_at, notes, credits_charged, error_message, error_code, created_at, updated_at, completed_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/templatefox/models/agent_job_status_response.rb', line 210

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @credits_charged.nil?
    invalid_properties.push('invalid value for "credits_charged", credits_charged cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/templatefox/models/agent_job_status_response.rb', line 372

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/templatefox/models/agent_job_status_response.rb', line 242

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @kind.nil?
  kind_validator = EnumAttributeValidator.new('String', ["create", "revise"])
  return false unless kind_validator.valid?(@kind)
  return false if @status.nil?
  return false if @credits_charged.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end