Class: TemplateFox::CreateVersionRequest

Inherits:
ApiModelBase show all
Defined in:
lib/templatefox/models/create_version_request.rb

Overview

Request to create a version snapshot

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateVersionRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/templatefox/models/create_version_request.rb', line 59

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TemplateFox::CreateVersionRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TemplateFox::CreateVersionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'tag')
    self.tag = attributes[:'tag']
  else
    self.tag = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end
end

Instance Attribute Details

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/templatefox/models/create_version_request.rb', line 22

def description
  @description
end

#tagObject

Version tag (e.g. ‘prod’, ‘staging’, ‘v1’). Lowercase alphanumeric with hyphens/underscores, 2-50 chars.



20
21
22
# File 'lib/templatefox/models/create_version_request.rb', line 20

def tag
  @tag
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



33
34
35
# File 'lib/templatefox/models/create_version_request.rb', line 33

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



38
39
40
# File 'lib/templatefox/models/create_version_request.rb', line 38

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
# File 'lib/templatefox/models/create_version_request.rb', line 25

def self.attribute_map
  {
    :'tag' => :'tag',
    :'description' => :'description'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/templatefox/models/create_version_request.rb', line 182

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



51
52
53
54
55
# File 'lib/templatefox/models/create_version_request.rb', line 51

def self.openapi_nullable
  Set.new([
    :'description'
  ])
end

.openapi_typesObject

Attribute type mapping.



43
44
45
46
47
48
# File 'lib/templatefox/models/create_version_request.rb', line 43

def self.openapi_types
  {
    :'tag' => :'String',
    :'description' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



160
161
162
163
164
165
# File 'lib/templatefox/models/create_version_request.rb', line 160

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      tag == o.tag &&
      description == o.description
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


169
170
171
# File 'lib/templatefox/models/create_version_request.rb', line 169

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



175
176
177
# File 'lib/templatefox/models/create_version_request.rb', line 175

def hash
  [tag, description].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/templatefox/models/create_version_request.rb', line 86

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @tag.nil?
    invalid_properties.push('invalid value for "tag", tag cannot be nil.')
  end

  if @tag.to_s.length > 50
    invalid_properties.push('invalid value for "tag", the character length must be smaller than or equal to 50.')
  end

  if @tag.to_s.length < 2
    invalid_properties.push('invalid value for "tag", the character length must be greater than or equal to 2.')
  end

  pattern = Regexp.new(/^[a-z0-9][a-z0-9_-]{0,48}[a-z0-9]$/)
  if @tag !~ pattern
    invalid_properties.push("invalid value for \"tag\", must conform to the pattern #{pattern}.")
  end

  if !@description.nil? && @description.to_s.length > 500
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 500.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/templatefox/models/create_version_request.rb', line 204

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



115
116
117
118
119
120
121
122
123
# File 'lib/templatefox/models/create_version_request.rb', line 115

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @tag.nil?
  return false if @tag.to_s.length > 50
  return false if @tag.to_s.length < 2
  return false if @tag !~ Regexp.new(/^[a-z0-9][a-z0-9_-]{0,48}[a-z0-9]$/)
  return false if !@description.nil? && @description.to_s.length > 500
  true
end