Class: TemplateFox::ExtractPdfPagesRequest

Inherits:
ApiModelBase show all
Defined in:
lib/templatefox/models/extract_pdf_pages_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ExtractPdfPagesRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TemplateFox::ExtractPdfPagesRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TemplateFox::ExtractPdfPagesRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'export_type')
    self.export_type = attributes[:'export_type']
  end

  if attributes.key?(:'expiration')
    self.expiration = attributes[:'expiration']
  else
    self.expiration = 86400
  end

  if attributes.key?(:'filename')
    self.filename = attributes[:'filename']
  end

  if attributes.key?(:'pdf_url')
    self.pdf_url = attributes[:'pdf_url']
  end

  if attributes.key?(:'pdf_base64')
    self.pdf_base64 = attributes[:'pdf_base64']
  end

  if attributes.key?(:'pages')
    self.pages = attributes[:'pages']
  else
    self.pages = nil
  end
end

Instance Attribute Details

#expirationObject

URL expiration in seconds. Min 60, max 604800. Only applies to ‘url` export type.



22
23
24
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 22

def expiration
  @expiration
end

#export_typeObject

‘url` uploads to CDN and returns URL, `binary` returns raw PDF bytes



19
20
21
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 19

def export_type
  @export_type
end

#filenameObject

Returns the value of attribute filename.



24
25
26
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 24

def filename
  @filename
end

#pagesObject

1-indexed page selection. Supports ranges and singles separated by commas, e.g. ‘1-3, 5, 7-9`. Order is preserved (`5,1,3` outputs those 3 pages in that order).



31
32
33
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 31

def pages
  @pages
end

#pdf_base64Object

Returns the value of attribute pdf_base64.



28
29
30
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 28

def pdf_base64
  @pdf_base64
end

#pdf_urlObject

Returns the value of attribute pdf_url.



26
27
28
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 26

def pdf_url
  @pdf_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 56

def self.attribute_map
  {
    :'export_type' => :'export_type',
    :'expiration' => :'expiration',
    :'filename' => :'filename',
    :'pdf_url' => :'pdf_url',
    :'pdf_base64' => :'pdf_base64',
    :'pages' => :'pages'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 255

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



90
91
92
93
94
95
96
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 90

def self.openapi_nullable
  Set.new([
    :'filename',
    :'pdf_url',
    :'pdf_base64',
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 78

def self.openapi_types
  {
    :'export_type' => :'AppRoutersV1PdfToolsExportType',
    :'expiration' => :'Integer',
    :'filename' => :'String',
    :'pdf_url' => :'String',
    :'pdf_base64' => :'String',
    :'pages' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



229
230
231
232
233
234
235
236
237
238
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 229

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      export_type == o.export_type &&
      expiration == o.expiration &&
      filename == o.filename &&
      pdf_url == o.pdf_url &&
      pdf_base64 == o.pdf_base64 &&
      pages == o.pages
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


242
243
244
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 242

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



248
249
250
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 248

def hash
  [export_type, expiration, filename, pdf_url, pdf_base64, pages].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 145

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@expiration.nil? && @expiration > 604800
    invalid_properties.push('invalid value for "expiration", must be smaller than or equal to 604800.')
  end

  if !@expiration.nil? && @expiration < 60
    invalid_properties.push('invalid value for "expiration", must be greater than or equal to 60.')
  end

  if !@filename.nil? && @filename.to_s.length > 100
    invalid_properties.push('invalid value for "filename", the character length must be smaller than or equal to 100.')
  end

  pattern = Regexp.new(/^[a-zA-Z0-9_\-\.]+$/)
  if !@filename.nil? && @filename !~ pattern
    invalid_properties.push("invalid value for \"filename\", must conform to the pattern #{pattern}.")
  end

  if @pages.nil?
    invalid_properties.push('invalid value for "pages", pages cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 277

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
177
178
179
180
181
182
# File 'lib/templatefox/models/extract_pdf_pages_request.rb', line 174

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@expiration.nil? && @expiration > 604800
  return false if !@expiration.nil? && @expiration < 60
  return false if !@filename.nil? && @filename.to_s.length > 100
  return false if !@filename.nil? && @filename !~ Regexp.new(/^[a-zA-Z0-9_\-\.]+$/)
  return false if @pages.nil?
  true
end