Class: TemplateFox::IntegrationsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/templatefox/api/integrations_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ IntegrationsApi

Returns a new instance of IntegrationsApi.



19
20
21
# File 'lib/templatefox/api/integrations_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/templatefox/api/integrations_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#delete_s3_config(opts = {}) ⇒ S3SuccessResponse

Delete S3 configuration Delete S3 storage configuration. Authentication: API Key required (‘x-api-key` header) Usage: Remove your S3 integration. Generated PDFs will use the default CDN storage after deletion. Warning: This action is irreversible. You’ll need to reconfigure S3 to use it again. **No credits consumed:** This is a configuration endpoint. **Rate Limits:** 60 requests/min (free), 120 requests/min (paid). Headers included in response.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



26
27
28
29
# File 'lib/templatefox/api/integrations_api.rb', line 26

def delete_s3_config(opts = {})
  data, _status_code, _headers = delete_s3_config_with_http_info(opts)
  data
end

#delete_s3_config_with_http_info(opts = {}) ⇒ Array<(S3SuccessResponse, Integer, Hash)>

Delete S3 configuration Delete S3 storage configuration. Authentication: API Key required (&#x60;x-api-key&#x60; header) Usage: Remove your S3 integration. Generated PDFs will use the default CDN storage after deletion. Warning: This action is irreversible. You&#39;ll need to reconfigure S3 to use it again. **No credits consumed:** This is a configuration endpoint. **Rate Limits:** 60 requests/min (free), 120 requests/min (paid). Headers included in response.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(S3SuccessResponse, Integer, Hash)>)

    S3SuccessResponse data, response status code and response headers



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/templatefox/api/integrations_api.rb', line 35

def delete_s3_config_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IntegrationsApi.delete_s3_config ...'
  end
  # resource path
  local_var_path = '/v1/integrations/s3'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'S3SuccessResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"IntegrationsApi.delete_s3_config",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IntegrationsApi#delete_s3_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_s3_config(opts = {}) ⇒ S3ConfigResponse

Get S3 configuration Get current S3 storage configuration. Authentication: API Key required (‘x-api-key` header) Usage: Retrieve your S3 integration settings. Secret access key is masked for security. **Returns 404** if S3 is not configured. **No credits consumed:** This is a read-only endpoint. **Rate Limits:** 60 requests/min (free), 120 requests/min (paid). Headers included in response.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



83
84
85
86
# File 'lib/templatefox/api/integrations_api.rb', line 83

def get_s3_config(opts = {})
  data, _status_code, _headers = get_s3_config_with_http_info(opts)
  data
end

#get_s3_config_with_http_info(opts = {}) ⇒ Array<(S3ConfigResponse, Integer, Hash)>

Get S3 configuration Get current S3 storage configuration. Authentication: API Key required (&#x60;x-api-key&#x60; header) Usage: Retrieve your S3 integration settings. Secret access key is masked for security. **Returns 404** if S3 is not configured. **No credits consumed:** This is a read-only endpoint. **Rate Limits:** 60 requests/min (free), 120 requests/min (paid). Headers included in response.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(S3ConfigResponse, Integer, Hash)>)

    S3ConfigResponse data, response status code and response headers



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/templatefox/api/integrations_api.rb', line 92

def get_s3_config_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IntegrationsApi.get_s3_config ...'
  end
  # resource path
  local_var_path = '/v1/integrations/s3'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'S3ConfigResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"IntegrationsApi.get_s3_config",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IntegrationsApi#get_s3_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#save_s3_config(s3_config_request, opts = {}) ⇒ S3SuccessResponse

Save S3 configuration Save or update S3-compatible storage configuration. Authentication: API Key required (‘x-api-key` header) Usage: Configure your S3-compatible storage to receive generated PDFs directly in your own bucket instead of the default CDN. **Supported providers:** - Amazon S3 - DigitalOcean Spaces - Cloudflare R2 - MinIO - Any S3-compatible storage **Secret key behavior:** - For new configuration: `secret_access_key` is required - For updates: Omit `secret_access_key` to keep existing value **No credits consumed:** This is a configuration endpoint. **Rate Limits:** 60 requests/min (free), 120 requests/min (paid). Headers included in response.

Parameters:

  • s3_config_request (S3ConfigRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



141
142
143
144
# File 'lib/templatefox/api/integrations_api.rb', line 141

def save_s3_config(s3_config_request, opts = {})
  data, _status_code, _headers = save_s3_config_with_http_info(s3_config_request, opts)
  data
end

#save_s3_config_with_http_info(s3_config_request, opts = {}) ⇒ Array<(S3SuccessResponse, Integer, Hash)>

Save S3 configuration Save or update S3-compatible storage configuration. Authentication: API Key required (&#x60;x-api-key&#x60; header) Usage: Configure your S3-compatible storage to receive generated PDFs directly in your own bucket instead of the default CDN. **Supported providers:** - Amazon S3 - DigitalOcean Spaces - Cloudflare R2 - MinIO - Any S3-compatible storage **Secret key behavior:** - For new configuration: &#x60;secret_access_key&#x60; is required - For updates: Omit &#x60;secret_access_key&#x60; to keep existing value **No credits consumed:** This is a configuration endpoint. **Rate Limits:** 60 requests/min (free), 120 requests/min (paid). Headers included in response.

Parameters:

  • s3_config_request (S3ConfigRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(S3SuccessResponse, Integer, Hash)>)

    S3SuccessResponse data, response status code and response headers



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/templatefox/api/integrations_api.rb', line 151

def save_s3_config_with_http_info(s3_config_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IntegrationsApi.save_s3_config ...'
  end
  # verify the required parameter 's3_config_request' is set
  if @api_client.config.client_side_validation && s3_config_request.nil?
    fail ArgumentError, "Missing the required parameter 's3_config_request' when calling IntegrationsApi.save_s3_config"
  end
  # resource path
  local_var_path = '/v1/integrations/s3'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(s3_config_request)

  # return_type
  return_type = opts[:debug_return_type] || 'S3SuccessResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"IntegrationsApi.save_s3_config",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IntegrationsApi#save_s3_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#test_s3_connection(opts = {}) ⇒ S3TestResponse

Test S3 connection Test S3 connection with stored credentials. Authentication: API Key required (‘x-api-key` header) Usage: Verify your S3 configuration is working correctly. The test will: 1. Connect to the endpoint 2. Verify bucket access 3. Check write permissions by uploading a small test file Prerequisite: S3 must be configured first using `POST /v1/integrations/s3` **No credits consumed:** This is a diagnostic endpoint. **Rate Limits:** 60 requests/min (free), 120 requests/min (paid). Headers included in response.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



208
209
210
211
# File 'lib/templatefox/api/integrations_api.rb', line 208

def test_s3_connection(opts = {})
  data, _status_code, _headers = test_s3_connection_with_http_info(opts)
  data
end

#test_s3_connection_with_http_info(opts = {}) ⇒ Array<(S3TestResponse, Integer, Hash)>

Test S3 connection Test S3 connection with stored credentials. Authentication: API Key required (&#x60;x-api-key&#x60; header) Usage: Verify your S3 configuration is working correctly. The test will: 1. Connect to the endpoint 2. Verify bucket access 3. Check write permissions by uploading a small test file Prerequisite: S3 must be configured first using &#x60;POST /v1/integrations/s3&#x60; **No credits consumed:** This is a diagnostic endpoint. **Rate Limits:** 60 requests/min (free), 120 requests/min (paid). Headers included in response.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(S3TestResponse, Integer, Hash)>)

    S3TestResponse data, response status code and response headers



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/templatefox/api/integrations_api.rb', line 217

def test_s3_connection_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IntegrationsApi.test_s3_connection ...'
  end
  # resource path
  local_var_path = '/v1/integrations/s3/test'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'S3TestResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"IntegrationsApi.test_s3_connection",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IntegrationsApi#test_s3_connection\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end