Class: TemplateFox::Modification

Inherits:
ApiModelBase show all
Defined in:
lib/templatefox/models/modification.rb

Overview

A single element modification, addressed by layer name.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Modification

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/templatefox/models/modification.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TemplateFox::Modification` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TemplateFox::Modification`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  end

  if attributes.key?(:'image_url')
    self.image_url = attributes[:'image_url']
  end

  if attributes.key?(:'color')
    self.color = attributes[:'color']
  end

  if attributes.key?(:'background')
    self.background = attributes[:'background']
  end

  if attributes.key?(:'hidden')
    self.hidden = attributes[:'hidden']
  end
end

Instance Attribute Details

#backgroundObject

Returns the value of attribute background.



28
29
30
# File 'lib/templatefox/models/modification.rb', line 28

def background
  @background
end

#colorObject

Returns the value of attribute color.



26
27
28
# File 'lib/templatefox/models/modification.rb', line 26

def color
  @color
end

#hiddenObject

Returns the value of attribute hidden.



30
31
32
# File 'lib/templatefox/models/modification.rb', line 30

def hidden
  @hidden
end

#image_urlObject

Returns the value of attribute image_url.



24
25
26
# File 'lib/templatefox/models/modification.rb', line 24

def image_url
  @image_url
end

#nameObject

Name of the layer to modify (set via the editor's Layers panel). Matched against the element's data-layer-name, falling back to its id.



20
21
22
# File 'lib/templatefox/models/modification.rb', line 20

def name
  @name
end

#textObject

Returns the value of attribute text.



22
23
24
# File 'lib/templatefox/models/modification.rb', line 22

def text
  @text
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/templatefox/models/modification.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/templatefox/models/modification.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
# File 'lib/templatefox/models/modification.rb', line 33

def self.attribute_map
  {
    :'name' => :'name',
    :'text' => :'text',
    :'image_url' => :'image_url',
    :'color' => :'color',
    :'background' => :'background',
    :'hidden' => :'hidden'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/templatefox/models/modification.rb', line 267

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
71
72
73
74
75
# File 'lib/templatefox/models/modification.rb', line 67

def self.openapi_nullable
  Set.new([
    :'text',
    :'image_url',
    :'color',
    :'background',
    :'hidden'
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
# File 'lib/templatefox/models/modification.rb', line 55

def self.openapi_types
  {
    :'name' => :'String',
    :'text' => :'String',
    :'image_url' => :'String',
    :'color' => :'String',
    :'background' => :'String',
    :'hidden' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



241
242
243
244
245
246
247
248
249
250
# File 'lib/templatefox/models/modification.rb', line 241

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      text == o.text &&
      image_url == o.image_url &&
      color == o.color &&
      background == o.background &&
      hidden == o.hidden
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


254
255
256
# File 'lib/templatefox/models/modification.rb', line 254

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



260
261
262
# File 'lib/templatefox/models/modification.rb', line 260

def hash
  [name, text, image_url, color, background, hidden].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/templatefox/models/modification.rb', line 122

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 200
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 200.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@text.nil? && @text.to_s.length > 10000
    invalid_properties.push('invalid value for "text", the character length must be smaller than or equal to 10000.')
  end

  if !@image_url.nil? && @image_url.to_s.length > 2000
    invalid_properties.push('invalid value for "image_url", the character length must be smaller than or equal to 2000.')
  end

  pattern = Regexp.new(/^https?:\/\//)
  if !@image_url.nil? && @image_url !~ pattern
    invalid_properties.push("invalid value for \"image_url\", must conform to the pattern #{pattern}.")
  end

  if !@color.nil? && @color.to_s.length > 100
    invalid_properties.push('invalid value for "color", the character length must be smaller than or equal to 100.')
  end

  if !@background.nil? && @background.to_s.length > 100
    invalid_properties.push('invalid value for "background", the character length must be smaller than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/templatefox/models/modification.rb', line 289

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/templatefox/models/modification.rb', line 163

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length > 200
  return false if @name.to_s.length < 1
  return false if !@text.nil? && @text.to_s.length > 10000
  return false if !@image_url.nil? && @image_url.to_s.length > 2000
  return false if !@image_url.nil? && @image_url !~ Regexp.new(/^https?:\/\//)
  return false if !@color.nil? && @color.to_s.length > 100
  return false if !@background.nil? && @background.to_s.length > 100
  true
end