Class: TemplateFox::PDFToolsApi
- Inherits:
-
Object
- Object
- TemplateFox::PDFToolsApi
- Defined in:
- lib/templatefox/api/pdf_tools_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#extract_pdf_pages(extract_pdf_pages_request, opts = {}) ⇒ PdfToolsResponse
Extract pages from a PDF Return a single PDF containing only the selected pages of the input, in the order specified.
-
#extract_pdf_pages_with_http_info(extract_pdf_pages_request, opts = {}) ⇒ Array<(PdfToolsResponse, Integer, Hash)>
Extract pages from a PDF Return a single PDF containing only the selected pages of the input, in the order specified.
-
#initialize(api_client = ApiClient.default) ⇒ PDFToolsApi
constructor
A new instance of PDFToolsApi.
-
#merge_pdf(merge_pdf_request, opts = {}) ⇒ PdfToolsResponse
Merge PDFs Concatenate 2 or more PDFs into a single PDF, in the order provided.
-
#merge_pdf_with_http_info(merge_pdf_request, opts = {}) ⇒ Array<(PdfToolsResponse, Integer, Hash)>
Merge PDFs Concatenate 2 or more PDFs into a single PDF, in the order provided.
-
#rotate_pdf(rotate_pdf_request, opts = {}) ⇒ PdfToolsResponse
Rotate pages of a PDF Rotate every page by the same angle (‘rotation`), or apply a per-page rotation map (`page_rotations`).
-
#rotate_pdf_with_http_info(rotate_pdf_request, opts = {}) ⇒ Array<(PdfToolsResponse, Integer, Hash)>
Rotate pages of a PDF Rotate every page by the same angle (`rotation`), or apply a per-page rotation map (`page_rotations`).
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PDFToolsApi
Returns a new instance of PDFToolsApi.
19 20 21 |
# File 'lib/templatefox/api/pdf_tools_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/templatefox/api/pdf_tools_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#extract_pdf_pages(extract_pdf_pages_request, opts = {}) ⇒ PdfToolsResponse
Extract pages from a PDF Return a single PDF containing only the selected pages of the input, in the order specified. Replaces the need for splitting + reassembling client-side. **Pages syntax:** 1-indexed, comma-separated. Supports ranges (‘1-3`) and singles (`5`). Order is preserved: `5,1,3` outputs those 3 pages in that order. Credits: 1 credit per call.
27 28 29 30 |
# File 'lib/templatefox/api/pdf_tools_api.rb', line 27 def extract_pdf_pages(extract_pdf_pages_request, opts = {}) data, _status_code, _headers = extract_pdf_pages_with_http_info(extract_pdf_pages_request, opts) data end |
#extract_pdf_pages_with_http_info(extract_pdf_pages_request, opts = {}) ⇒ Array<(PdfToolsResponse, Integer, Hash)>
Extract pages from a PDF Return a single PDF containing only the selected pages of the input, in the order specified. Replaces the need for splitting + reassembling client-side. **Pages syntax:** 1-indexed, comma-separated. Supports ranges (`1-3`) and singles (`5`). Order is preserved: `5,1,3` outputs those 3 pages in that order. Credits: 1 credit per call.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/templatefox/api/pdf_tools_api.rb', line 37 def extract_pdf_pages_with_http_info(extract_pdf_pages_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PDFToolsApi.extract_pdf_pages ...' end # verify the required parameter 'extract_pdf_pages_request' is set if @api_client.config.client_side_validation && extract_pdf_pages_request.nil? fail ArgumentError, "Missing the required parameter 'extract_pdf_pages_request' when calling PDFToolsApi.extract_pdf_pages" end # resource path local_var_path = '/v1/pdf-tools/extract-pages' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(extract_pdf_pages_request) # return_type return_type = opts[:debug_return_type] || 'PdfToolsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"PDFToolsApi.extract_pdf_pages", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PDFToolsApi#extract_pdf_pages\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#merge_pdf(merge_pdf_request, opts = {}) ⇒ PdfToolsResponse
Merge PDFs Concatenate 2 or more PDFs into a single PDF, in the order provided. Each input PDF is supplied as either an HTTPS URL or a base64 string. Credits: 1 credit per call.
95 96 97 98 |
# File 'lib/templatefox/api/pdf_tools_api.rb', line 95 def merge_pdf(merge_pdf_request, opts = {}) data, _status_code, _headers = merge_pdf_with_http_info(merge_pdf_request, opts) data end |
#merge_pdf_with_http_info(merge_pdf_request, opts = {}) ⇒ Array<(PdfToolsResponse, Integer, Hash)>
Merge PDFs Concatenate 2 or more PDFs into a single PDF, in the order provided. Each input PDF is supplied as either an HTTPS URL or a base64 string. Credits: 1 credit per call.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/templatefox/api/pdf_tools_api.rb', line 105 def merge_pdf_with_http_info(merge_pdf_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PDFToolsApi.merge_pdf ...' end # verify the required parameter 'merge_pdf_request' is set if @api_client.config.client_side_validation && merge_pdf_request.nil? fail ArgumentError, "Missing the required parameter 'merge_pdf_request' when calling PDFToolsApi.merge_pdf" end # resource path local_var_path = '/v1/pdf-tools/merge' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(merge_pdf_request) # return_type return_type = opts[:debug_return_type] || 'PdfToolsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"PDFToolsApi.merge_pdf", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PDFToolsApi#merge_pdf\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#rotate_pdf(rotate_pdf_request, opts = {}) ⇒ PdfToolsResponse
Rotate pages of a PDF Rotate every page by the same angle (‘rotation`), or apply a per-page rotation map (`page_rotations`). Rotations are cumulative with the page’s existing rotation. Allowed angles: 0, 90, 180, 270. Credits: 1 credit per call.
163 164 165 166 |
# File 'lib/templatefox/api/pdf_tools_api.rb', line 163 def rotate_pdf(rotate_pdf_request, opts = {}) data, _status_code, _headers = rotate_pdf_with_http_info(rotate_pdf_request, opts) data end |
#rotate_pdf_with_http_info(rotate_pdf_request, opts = {}) ⇒ Array<(PdfToolsResponse, Integer, Hash)>
Rotate pages of a PDF Rotate every page by the same angle (`rotation`), or apply a per-page rotation map (`page_rotations`). Rotations are cumulative with the page's existing rotation. Allowed angles: 0, 90, 180, 270. Credits: 1 credit per call.
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/templatefox/api/pdf_tools_api.rb', line 173 def rotate_pdf_with_http_info(rotate_pdf_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PDFToolsApi.rotate_pdf ...' end # verify the required parameter 'rotate_pdf_request' is set if @api_client.config.client_side_validation && rotate_pdf_request.nil? fail ArgumentError, "Missing the required parameter 'rotate_pdf_request' when calling PDFToolsApi.rotate_pdf" end # resource path local_var_path = '/v1/pdf-tools/rotate' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(rotate_pdf_request) # return_type return_type = opts[:debug_return_type] || 'PdfToolsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"PDFToolsApi.rotate_pdf", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PDFToolsApi#rotate_pdf\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |