Class: TemplateFox::ReviseAgentTemplateRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TemplateFox::ReviseAgentTemplateRequest
- Defined in:
- lib/templatefox/models/revise_agent_template_request.rb
Instance Attribute Summary collapse
-
#brand ⇒ Object
Returns the value of attribute brand.
-
#feedback ⇒ Object
Natural-language feedback on the current template.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ReviseAgentTemplateRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ReviseAgentTemplateRequest
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/templatefox/models/revise_agent_template_request.rb', line 58 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TemplateFox::ReviseAgentTemplateRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TemplateFox::ReviseAgentTemplateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'feedback') self.feedback = attributes[:'feedback'] else self.feedback = nil end if attributes.key?(:'brand') self.brand = attributes[:'brand'] end end |
Instance Attribute Details
#brand ⇒ Object
Returns the value of attribute brand.
21 22 23 |
# File 'lib/templatefox/models/revise_agent_template_request.rb', line 21 def brand @brand end |
#feedback ⇒ Object
Natural-language feedback on the current template.
19 20 21 |
# File 'lib/templatefox/models/revise_agent_template_request.rb', line 19 def feedback @feedback end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
32 33 34 |
# File 'lib/templatefox/models/revise_agent_template_request.rb', line 32 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
37 38 39 |
# File 'lib/templatefox/models/revise_agent_template_request.rb', line 37 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 |
# File 'lib/templatefox/models/revise_agent_template_request.rb', line 24 def self.attribute_map { :'feedback' => :'feedback', :'brand' => :'brand' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/templatefox/models/revise_agent_template_request.rb', line 155 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
50 51 52 53 54 |
# File 'lib/templatefox/models/revise_agent_template_request.rb', line 50 def self.openapi_nullable Set.new([ :'brand' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 |
# File 'lib/templatefox/models/revise_agent_template_request.rb', line 42 def self.openapi_types { :'feedback' => :'String', :'brand' => :'BrandInputs' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
133 134 135 136 137 138 |
# File 'lib/templatefox/models/revise_agent_template_request.rb', line 133 def ==(o) return true if self.equal?(o) self.class == o.class && feedback == o.feedback && brand == o.brand end |
#eql?(o) ⇒ Boolean
142 143 144 |
# File 'lib/templatefox/models/revise_agent_template_request.rb', line 142 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
148 149 150 |
# File 'lib/templatefox/models/revise_agent_template_request.rb', line 148 def hash [feedback, brand].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/templatefox/models/revise_agent_template_request.rb', line 85 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @feedback.nil? invalid_properties.push('invalid value for "feedback", feedback cannot be nil.') end if @feedback.to_s.length > 4000 invalid_properties.push('invalid value for "feedback", the character length must be smaller than or equal to 4000.') end if @feedback.to_s.length < 5 invalid_properties.push('invalid value for "feedback", the character length must be greater than or equal to 5.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/templatefox/models/revise_agent_template_request.rb', line 177 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
105 106 107 108 109 110 111 |
# File 'lib/templatefox/models/revise_agent_template_request.rb', line 105 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @feedback.nil? return false if @feedback.to_s.length > 4000 return false if @feedback.to_s.length < 5 true end |