Class: TemplateFox::TemplateField

Inherits:
ApiModelBase show all
Defined in:
lib/templatefox/models/template_field.rb

Overview

Field definition for template variables (compatible with Zapier and Make.com)

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TemplateField

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/templatefox/models/template_field.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TemplateFox::TemplateField` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TemplateFox::TemplateField`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  else
    self.label = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = 'string'
  end

  if attributes.key?(:'required')
    self.required = attributes[:'required']
  else
    self.required = false
  end

  if attributes.key?(:'help_text')
    self.help_text = attributes[:'help_text']
  end

  if attributes.key?(:'spec')
    if (value = attributes[:'spec']).is_a?(Array)
      self.spec = value
    end
  end
end

Instance Attribute Details

#help_textObject

Returns the value of attribute help_text.



31
32
33
# File 'lib/templatefox/models/template_field.rb', line 31

def help_text
  @help_text
end

#keyObject

Field key/identifier



20
21
22
# File 'lib/templatefox/models/template_field.rb', line 20

def key
  @key
end

#labelObject

Human-readable label



23
24
25
# File 'lib/templatefox/models/template_field.rb', line 23

def label
  @label
end

#requiredObject

Whether the field is required



29
30
31
# File 'lib/templatefox/models/template_field.rb', line 29

def required
  @required
end

#specObject

Returns the value of attribute spec.



33
34
35
# File 'lib/templatefox/models/template_field.rb', line 33

def spec
  @spec
end

#typeObject

Field type: string, integer, number, boolean, array



26
27
28
# File 'lib/templatefox/models/template_field.rb', line 26

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



48
49
50
# File 'lib/templatefox/models/template_field.rb', line 48

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



53
54
55
# File 'lib/templatefox/models/template_field.rb', line 53

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
# File 'lib/templatefox/models/template_field.rb', line 36

def self.attribute_map
  {
    :'key' => :'key',
    :'label' => :'label',
    :'type' => :'type',
    :'required' => :'required',
    :'help_text' => :'helpText',
    :'spec' => :'spec'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/templatefox/models/template_field.rb', line 201

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
74
75
# File 'lib/templatefox/models/template_field.rb', line 70

def self.openapi_nullable
  Set.new([
    :'help_text',
    :'spec'
  ])
end

.openapi_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
# File 'lib/templatefox/models/template_field.rb', line 58

def self.openapi_types
  {
    :'key' => :'String',
    :'label' => :'String',
    :'type' => :'String',
    :'required' => :'Boolean',
    :'help_text' => :'String',
    :'spec' => :'Array<TemplateFieldSpec>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



175
176
177
178
179
180
181
182
183
184
# File 'lib/templatefox/models/template_field.rb', line 175

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      key == o.key &&
      label == o.label &&
      type == o.type &&
      required == o.required &&
      help_text == o.help_text &&
      spec == o.spec
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


188
189
190
# File 'lib/templatefox/models/template_field.rb', line 188

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



194
195
196
# File 'lib/templatefox/models/template_field.rb', line 194

def hash
  [key, label, type, required, help_text, spec].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/templatefox/models/template_field.rb', line 130

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @label.nil?
    invalid_properties.push('invalid value for "label", label cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/templatefox/models/template_field.rb', line 223

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
150
151
# File 'lib/templatefox/models/template_field.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @key.nil?
  return false if @label.nil?
  true
end