Class: TemplateFox::Transaction
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TemplateFox::Transaction
- Defined in:
- lib/templatefox/models/transaction.rb
Overview
Transaction record
Instance Attribute Summary collapse
-
#created_at ⇒ Object
ISO 8601 timestamp.
-
#credits ⇒ Object
Credits consumed (positive) or added (negative).
-
#exec_tm ⇒ Object
Returns the value of attribute exec_tm.
-
#template_id ⇒ Object
Returns the value of attribute template_id.
-
#transaction_ref ⇒ Object
Unique transaction reference (UUID).
-
#transaction_type ⇒ Object
Transaction type: PDFGEN, PURCHASE, REFUND, BONUS.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Transaction
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Transaction
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/templatefox/models/transaction.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TemplateFox::Transaction` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TemplateFox::Transaction`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'transaction_ref') self.transaction_ref = attributes[:'transaction_ref'] else self.transaction_ref = nil end if attributes.key?(:'transaction_type') self.transaction_type = attributes[:'transaction_type'] else self.transaction_type = nil end if attributes.key?(:'template_id') self.template_id = attributes[:'template_id'] end if attributes.key?(:'exec_tm') self.exec_tm = attributes[:'exec_tm'] end if attributes.key?(:'credits') self.credits = attributes[:'credits'] else self.credits = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end end |
Instance Attribute Details
#created_at ⇒ Object
ISO 8601 timestamp
33 34 35 |
# File 'lib/templatefox/models/transaction.rb', line 33 def created_at @created_at end |
#credits ⇒ Object
Credits consumed (positive) or added (negative)
30 31 32 |
# File 'lib/templatefox/models/transaction.rb', line 30 def credits @credits end |
#exec_tm ⇒ Object
Returns the value of attribute exec_tm.
27 28 29 |
# File 'lib/templatefox/models/transaction.rb', line 27 def exec_tm @exec_tm end |
#template_id ⇒ Object
Returns the value of attribute template_id.
25 26 27 |
# File 'lib/templatefox/models/transaction.rb', line 25 def template_id @template_id end |
#transaction_ref ⇒ Object
Unique transaction reference (UUID)
20 21 22 |
# File 'lib/templatefox/models/transaction.rb', line 20 def transaction_ref @transaction_ref end |
#transaction_type ⇒ Object
Transaction type: PDFGEN, PURCHASE, REFUND, BONUS
23 24 25 |
# File 'lib/templatefox/models/transaction.rb', line 23 def transaction_type @transaction_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
48 49 50 |
# File 'lib/templatefox/models/transaction.rb', line 48 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
53 54 55 |
# File 'lib/templatefox/models/transaction.rb', line 53 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 |
# File 'lib/templatefox/models/transaction.rb', line 36 def self.attribute_map { :'transaction_ref' => :'transaction_ref', :'transaction_type' => :'transaction_type', :'template_id' => :'template_id', :'exec_tm' => :'exec_tm', :'credits' => :'credits', :'created_at' => :'created_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/templatefox/models/transaction.rb', line 229 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
70 71 72 73 74 75 |
# File 'lib/templatefox/models/transaction.rb', line 70 def self.openapi_nullable Set.new([ :'template_id', :'exec_tm', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 |
# File 'lib/templatefox/models/transaction.rb', line 58 def self.openapi_types { :'transaction_ref' => :'String', :'transaction_type' => :'String', :'template_id' => :'String', :'exec_tm' => :'Integer', :'credits' => :'Integer', :'created_at' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
203 204 205 206 207 208 209 210 211 212 |
# File 'lib/templatefox/models/transaction.rb', line 203 def ==(o) return true if self.equal?(o) self.class == o.class && transaction_ref == o.transaction_ref && transaction_type == o.transaction_type && template_id == o.template_id && exec_tm == o.exec_tm && credits == o.credits && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
216 217 218 |
# File 'lib/templatefox/models/transaction.rb', line 216 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
222 223 224 |
# File 'lib/templatefox/models/transaction.rb', line 222 def hash [transaction_ref, transaction_type, template_id, exec_tm, credits, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/templatefox/models/transaction.rb', line 128 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @transaction_ref.nil? invalid_properties.push('invalid value for "transaction_ref", transaction_ref cannot be nil.') end if @transaction_type.nil? invalid_properties.push('invalid value for "transaction_type", transaction_type cannot be nil.') end if @credits.nil? invalid_properties.push('invalid value for "credits", credits cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/templatefox/models/transaction.rb', line 251 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
152 153 154 155 156 157 158 159 |
# File 'lib/templatefox/models/transaction.rb', line 152 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @transaction_ref.nil? return false if @transaction_type.nil? return false if @credits.nil? return false if @created_at.nil? true end |