Class: TemplateFox::UpdateVersionRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TemplateFox::UpdateVersionRequest
- Defined in:
- lib/templatefox/models/update_version_request.rb
Overview
Request to update a version’s tag or description. Send null to clear a field.
Instance Attribute Summary collapse
-
#description ⇒ Object
Returns the value of attribute description.
-
#tag ⇒ Object
Returns the value of attribute tag.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateVersionRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateVersionRequest
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/templatefox/models/update_version_request.rb', line 59 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TemplateFox::UpdateVersionRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TemplateFox::UpdateVersionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tag') self.tag = attributes[:'tag'] end if attributes.key?(:'description') self.description = attributes[:'description'] end end |
Instance Attribute Details
#description ⇒ Object
Returns the value of attribute description.
21 22 23 |
# File 'lib/templatefox/models/update_version_request.rb', line 21 def description @description end |
#tag ⇒ Object
Returns the value of attribute tag.
19 20 21 |
# File 'lib/templatefox/models/update_version_request.rb', line 19 def tag @tag end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
32 33 34 |
# File 'lib/templatefox/models/update_version_request.rb', line 32 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
37 38 39 |
# File 'lib/templatefox/models/update_version_request.rb', line 37 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 |
# File 'lib/templatefox/models/update_version_request.rb', line 24 def self.attribute_map { :'tag' => :'tag', :'description' => :'description' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/templatefox/models/update_version_request.rb', line 162 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
50 51 52 53 54 55 |
# File 'lib/templatefox/models/update_version_request.rb', line 50 def self.openapi_nullable Set.new([ :'tag', :'description' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 |
# File 'lib/templatefox/models/update_version_request.rb', line 42 def self.openapi_types { :'tag' => :'String', :'description' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
140 141 142 143 144 145 |
# File 'lib/templatefox/models/update_version_request.rb', line 140 def ==(o) return true if self.equal?(o) self.class == o.class && tag == o.tag && description == o.description end |
#eql?(o) ⇒ Boolean
149 150 151 |
# File 'lib/templatefox/models/update_version_request.rb', line 149 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
155 156 157 |
# File 'lib/templatefox/models/update_version_request.rb', line 155 def hash [tag, description].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/templatefox/models/update_version_request.rb', line 84 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@tag.nil? && @tag.to_s.length > 50 invalid_properties.push('invalid value for "tag", the character length must be smaller than or equal to 50.') end pattern = Regexp.new(/^[a-z0-9][a-z0-9_-]{0,48}[a-z0-9]$/) if !@tag.nil? && @tag !~ pattern invalid_properties.push("invalid value for \"tag\", must conform to the pattern #{pattern}.") end if !@description.nil? && @description.to_s.length > 500 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 500.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/templatefox/models/update_version_request.rb', line 184 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
105 106 107 108 109 110 111 |
# File 'lib/templatefox/models/update_version_request.rb', line 105 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@tag.nil? && @tag.to_s.length > 50 return false if !@tag.nil? && @tag !~ Regexp.new(/^[a-z0-9][a-z0-9_-]{0,48}[a-z0-9]$/) return false if !@description.nil? && @description.to_s.length > 500 true end |