Class: TemplateFox::BrandInputs
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TemplateFox::BrandInputs
- Defined in:
- lib/templatefox/models/brand_inputs.rb
Overview
Optional brand constraints passed to the agent.
Instance Attribute Summary collapse
-
#asset_urls ⇒ Object
Public https:// URLs of assets (logo, photos) the agent may use.
-
#colors ⇒ Object
Brand colors as hex strings, e.g.
-
#fonts ⇒ Object
Preferred font families.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BrandInputs
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BrandInputs
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/templatefox/models/brand_inputs.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TemplateFox::BrandInputs` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TemplateFox::BrandInputs`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'colors') if (value = attributes[:'colors']).is_a?(Array) self.colors = value end end if attributes.key?(:'fonts') if (value = attributes[:'fonts']).is_a?(Array) self.fonts = value end end if attributes.key?(:'asset_urls') if (value = attributes[:'asset_urls']).is_a?(Array) self.asset_urls = value end end end |
Instance Attribute Details
#asset_urls ⇒ Object
Public https:// URLs of assets (logo, photos) the agent may use.
26 27 28 |
# File 'lib/templatefox/models/brand_inputs.rb', line 26 def asset_urls @asset_urls end |
#colors ⇒ Object
Brand colors as hex strings, e.g. ['#0C3C5F', '#E27D28']
20 21 22 |
# File 'lib/templatefox/models/brand_inputs.rb', line 20 def colors @colors end |
#fonts ⇒ Object
Preferred font families. Non-built-in fonts are substituted with the closest built-in and noted in the result.
23 24 25 |
# File 'lib/templatefox/models/brand_inputs.rb', line 23 def fonts @fonts end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/templatefox/models/brand_inputs.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/templatefox/models/brand_inputs.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 |
# File 'lib/templatefox/models/brand_inputs.rb', line 29 def self.attribute_map { :'colors' => :'colors', :'fonts' => :'fonts', :'asset_urls' => :'asset_urls' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/templatefox/models/brand_inputs.rb', line 194 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 |
# File 'lib/templatefox/models/brand_inputs.rb', line 57 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 |
# File 'lib/templatefox/models/brand_inputs.rb', line 48 def self.openapi_types { :'colors' => :'Array<String>', :'fonts' => :'Array<String>', :'asset_urls' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
171 172 173 174 175 176 177 |
# File 'lib/templatefox/models/brand_inputs.rb', line 171 def ==(o) return true if self.equal?(o) self.class == o.class && colors == o.colors && fonts == o.fonts && asset_urls == o.asset_urls end |
#eql?(o) ⇒ Boolean
181 182 183 |
# File 'lib/templatefox/models/brand_inputs.rb', line 181 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
187 188 189 |
# File 'lib/templatefox/models/brand_inputs.rb', line 187 def hash [colors, fonts, asset_urls].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/templatefox/models/brand_inputs.rb', line 99 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@colors.nil? && @colors.length > 8 invalid_properties.push('invalid value for "colors", number of items must be less than or equal to 8.') end if !@fonts.nil? && @fonts.length > 4 invalid_properties.push('invalid value for "fonts", number of items must be less than or equal to 4.') end if !@asset_urls.nil? && @asset_urls.length > 5 invalid_properties.push('invalid value for "asset_urls", number of items must be less than or equal to 5.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/templatefox/models/brand_inputs.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
119 120 121 122 123 124 125 |
# File 'lib/templatefox/models/brand_inputs.rb', line 119 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@colors.nil? && @colors.length > 8 return false if !@fonts.nil? && @fonts.length > 4 return false if !@asset_urls.nil? && @asset_urls.length > 5 true end |