Class: TemplateFox::CreateAgentTemplateRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TemplateFox::CreateAgentTemplateRequest
- Defined in:
- lib/templatefox/models/create_agent_template_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#brand ⇒ Object
Returns the value of attribute brand.
-
#height ⇒ Object
Returns the value of attribute height.
-
#instructions ⇒ Object
What the template should look like and which layers it needs, in natural language.
-
#name ⇒ Object
Template name.
-
#preset ⇒ Object
Returns the value of attribute preset.
-
#width ⇒ Object
Returns the value of attribute width.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAgentTemplateRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateAgentTemplateRequest
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TemplateFox::CreateAgentTemplateRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TemplateFox::CreateAgentTemplateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'instructions') self.instructions = attributes[:'instructions'] else self.instructions = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'preset') self.preset = attributes[:'preset'] end if attributes.key?(:'width') self.width = attributes[:'width'] end if attributes.key?(:'height') self.height = attributes[:'height'] end if attributes.key?(:'brand') self.brand = attributes[:'brand'] end end |
Instance Attribute Details
#brand ⇒ Object
Returns the value of attribute brand.
30 31 32 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 30 def brand @brand end |
#height ⇒ Object
Returns the value of attribute height.
28 29 30 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 28 def height @height end |
#instructions ⇒ Object
What the template should look like and which layers it needs, in natural language.
19 20 21 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 19 def instructions @instructions end |
#name ⇒ Object
Template name
22 23 24 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 22 def name @name end |
#preset ⇒ Object
Returns the value of attribute preset.
24 25 26 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 24 def preset @preset end |
#width ⇒ Object
Returns the value of attribute width.
26 27 28 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 26 def width @width end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 55 def self.attribute_map { :'instructions' => :'instructions', :'name' => :'name', :'preset' => :'preset', :'width' => :'width', :'height' => :'height', :'brand' => :'brand' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 312 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 93 94 95 96 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 89 def self.openapi_nullable Set.new([ :'preset', :'width', :'height', :'brand' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 86 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 77 def self.openapi_types { :'instructions' => :'String', :'name' => :'String', :'preset' => :'String', :'width' => :'Integer', :'height' => :'Integer', :'brand' => :'BrandInputs' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
286 287 288 289 290 291 292 293 294 295 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 286 def ==(o) return true if self.equal?(o) self.class == o.class && instructions == o.instructions && name == o.name && preset == o.preset && width == o.width && height == o.height && brand == o.brand end |
#eql?(o) ⇒ Boolean
299 300 301 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 299 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
305 306 307 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 305 def hash [instructions, name, preset, width, height, brand].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @instructions.nil? invalid_properties.push('invalid value for "instructions", instructions cannot be nil.') end if @instructions.to_s.length > 4000 invalid_properties.push('invalid value for "instructions", the character length must be smaller than or equal to 4000.') end if @instructions.to_s.length < 10 invalid_properties.push('invalid value for "instructions", the character length must be greater than or equal to 10.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 100 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@width.nil? && @width > 8000 invalid_properties.push('invalid value for "width", must be smaller than or equal to 8000.') end if !@width.nil? && @width < 16 invalid_properties.push('invalid value for "width", must be greater than or equal to 16.') end if !@height.nil? && @height > 8000 invalid_properties.push('invalid value for "height", must be smaller than or equal to 8000.') end if !@height.nil? && @height < 16 invalid_properties.push('invalid value for "height", must be greater than or equal to 16.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 334 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/templatefox/models/create_agent_template_request.rb', line 193 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @instructions.nil? return false if @instructions.to_s.length > 4000 return false if @instructions.to_s.length < 10 return false if @name.nil? return false if @name.to_s.length > 100 return false if @name.to_s.length < 1 preset_validator = EnumAttributeValidator.new('String', ["instagram-square", "instagram-story", "og-image", "twitter-card", "pinterest-pin", "square-512"]) return false unless preset_validator.valid?(@preset) return false if !@width.nil? && @width > 8000 return false if !@width.nil? && @width < 16 return false if !@height.nil? && @height > 8000 return false if !@height.nil? && @height < 16 true end |