Class: TemplateFox::MergePdfRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TemplateFox::MergePdfRequest
- Defined in:
- lib/templatefox/models/merge_pdf_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#expiration ⇒ Object
URL expiration in seconds.
-
#export_type ⇒ Object
‘url` uploads to CDN and returns URL, `binary` returns raw PDF bytes.
-
#filename ⇒ Object
Returns the value of attribute filename.
-
#pdfs ⇒ Object
Ordered list of PDFs to merge.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MergePdfRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MergePdfRequest
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/templatefox/models/merge_pdf_request.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TemplateFox::MergePdfRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TemplateFox::MergePdfRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'export_type') self.export_type = attributes[:'export_type'] end if attributes.key?(:'expiration') self.expiration = attributes[:'expiration'] else self.expiration = 86400 end if attributes.key?(:'filename') self.filename = attributes[:'filename'] end if attributes.key?(:'pdfs') if (value = attributes[:'pdfs']).is_a?(Array) self.pdfs = value end else self.pdfs = nil end end |
Instance Attribute Details
#expiration ⇒ Object
URL expiration in seconds. Min 60, max 604800. Only applies to ‘url` export type.
22 23 24 |
# File 'lib/templatefox/models/merge_pdf_request.rb', line 22 def expiration @expiration end |
#export_type ⇒ Object
‘url` uploads to CDN and returns URL, `binary` returns raw PDF bytes
19 20 21 |
# File 'lib/templatefox/models/merge_pdf_request.rb', line 19 def export_type @export_type end |
#filename ⇒ Object
Returns the value of attribute filename.
24 25 26 |
# File 'lib/templatefox/models/merge_pdf_request.rb', line 24 def filename @filename end |
#pdfs ⇒ Object
Ordered list of PDFs to merge. Each entry has either ‘pdf_url` or `pdf_base64`. Minimum 2.
27 28 29 |
# File 'lib/templatefox/models/merge_pdf_request.rb', line 27 def pdfs @pdfs end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/templatefox/models/merge_pdf_request.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/templatefox/models/merge_pdf_request.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 |
# File 'lib/templatefox/models/merge_pdf_request.rb', line 52 def self.attribute_map { :'export_type' => :'export_type', :'expiration' => :'expiration', :'filename' => :'filename', :'pdfs' => :'pdfs' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/templatefox/models/merge_pdf_request.rb', line 246 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 86 |
# File 'lib/templatefox/models/merge_pdf_request.rb', line 82 def self.openapi_nullable Set.new([ :'filename', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 |
# File 'lib/templatefox/models/merge_pdf_request.rb', line 72 def self.openapi_types { :'export_type' => :'AppRoutersV1PdfToolsExportType', :'expiration' => :'Integer', :'filename' => :'String', :'pdfs' => :'Array<PdfInput>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
222 223 224 225 226 227 228 229 |
# File 'lib/templatefox/models/merge_pdf_request.rb', line 222 def ==(o) return true if self.equal?(o) self.class == o.class && export_type == o.export_type && expiration == o.expiration && filename == o.filename && pdfs == o.pdfs end |
#eql?(o) ⇒ Boolean
233 234 235 |
# File 'lib/templatefox/models/merge_pdf_request.rb', line 233 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
239 240 241 |
# File 'lib/templatefox/models/merge_pdf_request.rb', line 239 def hash [export_type, expiration, filename, pdfs].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/templatefox/models/merge_pdf_request.rb', line 129 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@expiration.nil? && @expiration > 604800 invalid_properties.push('invalid value for "expiration", must be smaller than or equal to 604800.') end if !@expiration.nil? && @expiration < 60 invalid_properties.push('invalid value for "expiration", must be greater than or equal to 60.') end if !@filename.nil? && @filename.to_s.length > 100 invalid_properties.push('invalid value for "filename", the character length must be smaller than or equal to 100.') end pattern = Regexp.new(/^[a-zA-Z0-9_\-\.]+$/) if !@filename.nil? && @filename !~ pattern invalid_properties.push("invalid value for \"filename\", must conform to the pattern #{pattern}.") end if @pdfs.nil? invalid_properties.push('invalid value for "pdfs", pdfs cannot be nil.') end if @pdfs.length < 2 invalid_properties.push('invalid value for "pdfs", number of items must be greater than or equal to 2.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/templatefox/models/merge_pdf_request.rb', line 268 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
162 163 164 165 166 167 168 169 170 171 |
# File 'lib/templatefox/models/merge_pdf_request.rb', line 162 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@expiration.nil? && @expiration > 604800 return false if !@expiration.nil? && @expiration < 60 return false if !@filename.nil? && @filename.to_s.length > 100 return false if !@filename.nil? && @filename !~ Regexp.new(/^[a-zA-Z0-9_\-\.]+$/) return false if @pdfs.nil? return false if @pdfs.length < 2 true end |